# LanguageTools

Tools for language models.

```shell
pip install languagetools
```

```python
import languagetools as lt

summary = lt.summarizer.summarize(text)
```

This software is proprietary. All rights are reserved.
